@@ -2,7 +2,7 @@
 #
 
 BASH_BASE_SIZE=0x00001a0e
-CISCO_AC_TIMESTAMP=0x000000006144b713
+CISCO_AC_TIMESTAMP=0x0000000061b09222
 CISCO_AC_OBJNAME=iseposture_install.sh                                           
 # BASH_BASE_SIZE=0x00000000 is required for signing
 # the comment is after or else the code signing tool will find the comment
@@ -22,7 +22,7 @@ ISEPLUGINFILES="libacisectrl.so libaciseshim.so"
 ISEPOSTUREMANIFEST="ACManifestISEPosture.xml"
 VPNMANIFEST="${ANYCONNECT_INSTPREFIX}/ACManifestVPN.xml"
 
-LOGFNAME=`date "+anyconnect-linux64-4.10.03104-iseposture-%H%M%S%d%m%Y.log"`
+LOGFNAME=`date "+anyconnect-linux64-4.10.04071-iseposture-%H%M%S%d%m%Y.log"`
 CLIENTNAME="Cisco AnyConnect ISE Posture Module"
 CURRENTDIR=`dirname $0 2> /dev/null`
 
@@ -228,6 +228,12 @@ q`-euX0U#0E뢯˂1-Q!m0
 	*H
   >
 Z$",|%)v]-:0a~`=į* U7ђuQnZ^$N?qcK_Dy6FN\Q$$'*)(:q(<.%Gzhh\ \qh@@Dd%B26$/r~IEYtdkfCڳ
- Ι1c=OƓIbnS.hlD2fdQ  mBz,ҩ=9\ Rm<|Rz:N/&7Cg3+ۡ@*tƣ\1t=y9vCI}OTQeS@1aE:441Q价:}jYz4h|0p=hڕ-B?יUѣi~IynTlAq'
-v9@ 1m(BA˛_%' 'I YX)8v{^x*  A%WdF#ӧI̖Źrڱ
-,%1WP8ȟ"PsۗUdsRv9vkR"#"DU02s]tԹ~mǈ0Z0NՃ?_ߊ:&ARǏp!l7M!1n=埠8$Z*)!oqc`(ѵEa=<h6pl%5
\ No newline at end of file
+ Ι1c=OƓIbnS.hlD2fdQ  cUQ<JATT
+U]g Kh&IDH^\G2fcdL
+5R]
+iv1$$RY2q
+Sv8Ђ>69&o
+	*UȜǉ{|=hփ7]X\1~ofNڔ7<:>-JRADÏmFPAP9y
+~ZUfYH
+p!JD߳X~02VC||Pp^9|d  wb.WVͯ1a=:bE4Sq&ׯ+gl`}~WU#$N;w?"FքW^ic~%]~V)"zoH02D. oSmZu`(pz-)e
+(MQ*BЪGz/gnMIIi+z'3x %`ا6; 8'qA˲k|1d~\狘ᆘ퐽l
\ No newline at end of file
