@@ -138,8 +138,8 @@ killNVMAgent
 removeKDF
 
 # Remove service plugin
-echo "rm -f ${PLUGINDIR}/libacnvmctrl.so" >> ${UNINSTALLLOG}
-rm -f ${PLUGINDIR}/libacnvmctrl.so >> ${UNINSTALLLOG} 2>&1
+echo "rm -f ${INSTPREFIX}/libacnvmctrl.so" >> ${UNINSTALLLOG}
+rm -f ${INSTPREFIX}/libacnvmctrl.so >> ${UNINSTALLLOG} 2>&1
 
 # Remove only those files that we know we installed
 for FILE in ${COMMONFILELIST}; do
