@@ -14,7 +14,7 @@ checkVersionFeasibilityWithStandaloneNVM()
   failed=false
   # version of VPN being installed has to be greater than the installed standalone NVM version
   if [ -f ${NVMMANIFEST} ]; then
-      VPNVERSION=4.10.03104
+      VPNVERSION=4.10.04071
       NVMVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${NVMMANIFEST})
 
       if [ $(version $VPNVERSION) -lt $(version $NVMVERSION) ]; then
@@ -35,7 +35,7 @@ checkInstalledVersion()
   # version of VPN being installed has to be greater than the current VPN version
   if [ -f ${VPNMANIFEST} ]; then
       VPNPREVVERSION=$(awk -F"\"" '/file version/ { print $2 }' ${VPNMANIFEST})
-      VPNCURRVERSION=4.10.03104
+      VPNCURRVERSION=4.10.04071
 
       if [ $(version $VPNCURRVERSION) -le $(version $VPNPREVVERSION) ]; then
         failed=true
@@ -92,7 +92,7 @@ SYSVLEVELS="2 3 4 5"
 PREVDIR=`pwd`
 MARKER=$((`grep -an "[B]EGIN\ ARCHIVE" $0 | cut -d ":" -f 1` + 1))
 MARKER_END=$((`grep -an "[E]ND\ ARCHIVE" $0 | cut -d ":" -f 1` - 1))
-LOGFNAME=`date "+anyconnect-linux64-4.10.03104-core-vpn-webdeploy-k9-%H%M%S%d%m%Y.log"`
+LOGFNAME=`date "+anyconnect-linux64-4.10.04071-core-vpn-webdeploy-k9-%H%M%S%d%m%Y.log"`
 CLIENTNAME="Cisco AnyConnect Secure Mobility Client"
 FEEDBACK_DIR="${INSTPREFIX}/CustomerExperienceFeedback"
 
@@ -669,7 +669,7 @@ ${BINDIR}/acinstallhelper -acpolgen bd=${BYPASS_DOWNLOADER:-false} \
                                     uploc=${ALLOW_LOCALIZATION_UPDATES_FROM_ANY_SERVER:-true} \
                                     upal=${AUTHORIZED_SERVER_LIST} \
                                     rsc=${RESTRICT_SERVER_CERT_STORE:-false} \
-                                    or=${OCSP_REVOCATION:-false}
+                                    orc=${OCSP_REVOCATION:-false}
 
 # Attempt to install the init script in the proper place
 
