@@ -34,7 +34,7 @@ FILELIST="${BINDIR}/vpnagentd \
           ${LIBDIR}/libacciscocrypto.so \
           ${LIBDIR}/cfom.so \
           ${LIBDIR}/libaccurl.so.4 \
-          ${LIBDIR}/libaccurl.so.4.5.0 \
+          ${LIBDIR}/libaccurl.so.4.7.0 \
           ${LIBDIR}/libvpnagentutilities.so \
           ${LIBDIR}/libvpncommon.so \
           ${LIBDIR}/libvpncommoncrypt.so \
@@ -47,12 +47,13 @@ FILELIST="${BINDIR}/vpnagentd \
           ${PLUGINDIR}/libacdownloader.so \
           ${BINDIR}/acinstallhelper \
           ${BINDIR}/acwebhelper \
+          ${BINDIR}/acextwebhelper \
           ${BINDIR}/manifesttool \
           ${BINDIR}/manifesttool_vpn \
           ${BINDIR}/load_tun.sh \
           ${MENUDIR}/cisco-anyconnect.menu \
           ${DIRECTORYDIR}/cisco-anyconnect.directory \
-          ${DESKTOPDIR}/cisco-anyconnect.desktop \
+          ${DESKTOPDIR}/com.cisco.anyconnect.gui.desktop \
           ${ICONSDIR}/hicolor/48x48/apps/cisco-anyconnect.png \
           ${ICONSDIR}/hicolor/64x64/apps/cisco-anyconnect.png \
           ${ICONSDIR}/hicolor/96x96/apps/cisco-anyconnect.png \
